/* @import url("cubicweb.css"); */

/* template specific CSS */

table.matrix {
  width: 100%;
  border: collapse;
}

table.matrix td {
  border: 1px solid #ccc;
}

td.l0 {
  background: #000;
}

td.l1 {
  background: #f00;
}

td.l2 {
  background: #f90;
}

td.l3 {
  background: #cfc;
}

td.l4 {
  background: #8e8;
}

td.l5 {
  background: #0b0;
}

table.matrix td {
  text-align: right;
  font-size: 80%;
}

td.l0 a, td.l1 a, td.l2 a, td.l3 a, td.l4 a, td.l5 a {
  color: black;
  text-decoration: underline;
}

table.matrixHelp td.rateInfo {
  font-size: 70%;
  width: 6em;
  border: 1px solid #ccc;
}

table.matrixHelp td {
  padding-left: 1ex;
}

table.matrix tr:first-child th a {
  transform: rotate(-45deg);
  transform-origin: 0% 50%;
  position:absolute;
  display: inline-block;
}

table.matrix tr:first-child th {
  padding-top: 10em;
}
