add_package('ecomment')
# Talk entity type is added automatically by the add_package command
# but attribute order doesn't seem to be right, use synchronize to
# reset the order
print "please, restart the shell and execute synchronize_eschema('Talk')"
# synchronize_eschema('Talk')
